@@ -6,32 +6,28 @@
 
 # remove when we don't support py38 anymore
 from __future__ import annotations
-from typing import Any
+
 import argparse
+import configparser
+import logging
 import os
 import shutil
-import logging
-import configparser
 import sys
+from typing import Any
 
-from jinja2 import (
-    Environment,
-    ChoiceLoader,
-    FileSystemLoader,
-    PackageLoader,
-    Template,
-)
 import feedgenerator
+from jinja2 import Environment, FileSystemLoader, Template, TemplateNotFound
 
-from blag.markdown import markdown_factory, convert_markdown
+import blag
 from blag.devserver import serve
-from blag.version import __VERSION__
+from blag.markdown import convert_markdown, markdown_factory
 from blag.quickstart import quickstart
+from blag.version import __VERSION__
 
 logger = logging.getLogger(__name__)
 logging.basicConfig(
     level=logging.INFO,
-    format='%(asctime)s %(levelname)s %(name)s %(message)s',
+    format="%(asctime)s %(levelname)s %(name)s %(message)s",
 )
 
 
@@ -70,84 +66,84 @@ def parse_args(args: list[str] | None = None) -> argparse.Namespace:
     """
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        '--version',
-        action='version',
-        version='%(prog)s ' + __VERSION__,
+        "--version",
+        action="version",
+        version="%(prog)s " + __VERSION__,
     )
     parser.add_argument(
-        '-v',
-        '--verbose',
-        action='store_true',
-        help='Verbose output.',
+        "-v",
+        "--verbose",
+        action="store_true",
+        help="Verbose output.",
     )
 
-    commands = parser.add_subparsers(dest='command')
+    commands = parser.add_subparsers(dest="command")
     commands.required = True
 
     build_parser = commands.add_parser(
-        'build',
-        help='Build website.',
+        "build",
+        help="Build website.",
     )
     build_parser.set_defaults(func=build)
     build_parser.add_argument(
-        '-i',
-        '--input-dir',
-        default='content',
-        help='Input directory (default: content)',
+        "-i",
+        "--input-dir",
+        default="content",
+        help="Input directory (default: content)",
     )
     build_parser.add_argument(
-        '-o',
-        '--output-dir',
-        default='build',
-        help='Ouptut directory (default: build)',
+        "-o",
+        "--output-dir",
+        default="build",
+        help="Ouptut directory (default: build)",
     )
     build_parser.add_argument(
-        '-t',
-        '--template-dir',
-        default='templates',
-        help='Template directory (default: templates)',
+        "-t",
+        "--template-dir",
+        default="templates",
+        help="Template directory (default: templates)",
     )
     build_parser.add_argument(
-        '-s',
-        '--static-dir',
-        default='static',
-        help='Static directory (default: static)',
+        "-s",
+        "--static-dir",
+        default="static",
+        help="Static directory (default: static)",
     )
 
     quickstart_parser = commands.add_parser(
-        'quickstart',
+        "quickstart",
         help="Quickstart blag, creating necessary configuration.",
     )
     quickstart_parser.set_defaults(func=quickstart)
 
     serve_parser = commands.add_parser(
-        'serve',
+        "serve",
         help="Start development server.",
     )
     serve_parser.set_defaults(func=serve)
     serve_parser.add_argument(
-        '-i',
-        '--input-dir',
-        default='content',
-        help='Input directory (default: content)',
+        "-i",
+        "--input-dir",
+        default="content",
+        help="Input directory (default: content)",
     )
     serve_parser.add_argument(
-        '-o',
-        '--output-dir',
-        default='build',
-        help='Ouptut directory (default: build)',
+        "-o",
+        "--output-dir",
+        default="build",
+        help="Ouptut directory (default: build)",
     )
     serve_parser.add_argument(
-        '-t',
-        '--template-dir',
-        default='templates',
-        help='Template directory (default: templates)',
+        "-t",
+        "--template-dir",
+        default="templates",
+        help="Template directory (default: templates)",
     )
     serve_parser.add_argument(
-        '-s',
-        '--static-dir',
-        default='static',
-        help='Static directory (default: static)',
+        "-s",
+        "--static-dir",
+        default="static",
+        help="Static directory (default: static)",
     )
 
     return parser.parse_args(args)
@@ -170,30 +166,29 @@ def get_config(configfile: str) -> configparser.SectionProxy:
     config = configparser.ConfigParser()
     config.read(configfile)
     # check for the mandatory options
-    for value in 'base_url', 'title', 'description', 'author':
+    for value in "base_url", "title", "description", "author":
         try:
-            config['main'][value]
+            config["main"][value]
         except Exception:
-            print(f'{value} is missing in {configfile}!')
+            print(f"{value} is missing in {configfile}!")
             sys.exit(1)
 
-    if not config['main']['base_url'].endswith('/'):
-        logger.warning('base_url does not end with a slash, adding it.')
-        config['main']['base_url'] += '/'
+    if not config["main"]["base_url"].endswith("/"):
+        logger.warning("base_url does not end with a slash, adding it.")
+        config["main"]["base_url"] += "/"
 
-    return config['main']
+    return config["main"]
 
 
 def environment_factory(
-    template_dir: str | None = None,
+    template_dir: str,
     globals_: dict[str, object] | None = None,
 ) -> Environment:
     """Environment factory.
 
-    Creates a Jinja2 Environment with the default templates and
-    additional templates from `template_dir` loaded. If `globals` are
-    provided, they are attached to the environment and thus available to
-    all contexts.
+    Creates a Jinja2 Environment with the templates from `template_dir` loaded.
+    If `globals` are provided, they are attached to the environment and thus
+    available to all contexts.
 
     Parameters
     ----------
@@ -206,13 +201,7 @@ def environment_factory(
     jinja2.Environment
 
     """
-    # first we try the custom templates, and fall back the ones provided
-    # by blag
-    loaders: list[FileSystemLoader | PackageLoader] = []
-    if template_dir:
-        loaders.append(FileSystemLoader([template_dir]))
-    loaders.append(PackageLoader('blag', 'templates'))
-    env = Environment(loader=ChoiceLoader(loaders))
+    env = Environment(loader=FileSystemLoader(template_dir))
     if globals_:
         env.globals = globals_
     return env
@@ -229,43 +218,54 @@ def build(args: argparse.Namespace) -> None:
     args
 
     """
-    os.makedirs(f'{args.output_dir}', exist_ok=True)
+    os.makedirs(f"{args.output_dir}", exist_ok=True)
     convertibles = []
     for root, dirnames, filenames in os.walk(args.input_dir):
         for filename in filenames:
             rel_src = os.path.relpath(
-                f'{root}/{filename}', start=args.input_dir
+                f"{root}/{filename}", start=args.input_dir
             )
             # all non-markdown files are just copied over, the markdown
             # files are converted to html
-            if rel_src.endswith('.md'):
+            if rel_src.endswith(".md"):
                 rel_dst = rel_src
-                rel_dst = rel_dst[:-3] + '.html'
+                rel_dst = rel_dst[:-3] + ".html"
                 convertibles.append((rel_src, rel_dst))
             else:
                 shutil.copy(
-                    f'{args.input_dir}/{rel_src}',
-                    f'{args.output_dir}/{rel_src}',
+                    f"{args.input_dir}/{rel_src}",
+                    f"{args.output_dir}/{rel_src}",
                 )
         for dirname in dirnames:
             # all directories are copied into the output directory
-            path = os.path.relpath(f'{root}/{dirname}', start=args.input_dir)
-            os.makedirs(f'{args.output_dir}/{path}', exist_ok=True)
+            path = os.path.relpath(f"{root}/{dirname}", start=args.input_dir)
+            os.makedirs(f"{args.output_dir}/{path}", exist_ok=True)
 
     # copy static files over
-    logger.info('Copying static files.')
+    logger.info("Copying static files.")
     if os.path.exists(args.static_dir):
         shutil.copytree(args.static_dir, args.output_dir, dirs_exist_ok=True)
 
-    config = get_config('config.ini')
+    config = get_config("config.ini")
 
     env = environment_factory(args.template_dir, dict(site=config))
 
-    page_template = env.get_template('page.html')
-    article_template = env.get_template('article.html')
-    archive_template = env.get_template('archive.html')
-    tags_template = env.get_template('tags.html')
-    tag_template = env.get_template('tag.html')
+    try:
+        page_template = env.get_template("page.html")
+        article_template = env.get_template("article.html")
+        index_template = env.get_template("index.html")
+        archive_template = env.get_template("archive.html")
+        tags_template = env.get_template("tags.html")
+        tag_template = env.get_template("tag.html")
+    except TemplateNotFound as exc:
+        tmpl = os.path.join(blag.__path__[0], "templates")
+        logger.error(
+            f'Template "{exc.name}" not found in {args.template_dir}! '
+            "Consider running `blag quickstart` or copying the "
+            f"missing template from {tmpl}."
+        )
+
+        sys.exit(1)
 
     articles, pages = process_markdown(
         convertibles,
@@ -278,11 +278,12 @@ def build(args: argparse.Namespace) -> None:
     generate_feed(
         articles,
         args.output_dir,
-        base_url=config['base_url'],
-        blog_title=config['title'],
-        blog_description=config['description'],
-        blog_author=config['author'],
+        base_url=config["base_url"],
+        blog_title=config["title"],
+        blog_description=config["description"],
+        blog_author=config["author"],
     )
+    generate_index(articles, index_template, args.output_dir)
     generate_archive(articles, archive_template, args.output_dir)
     generate_tags(articles, tags_template, tag_template, args.output_dir)
 
@@ -302,6 +303,8 @@ def process_markdown(
     If a markdown file has a `date` metadata field it will be recognized
     as article otherwise as page.
 
+    Articles are sorted by date in descending order.
+
     Parameters
     ----------
     convertibles
@@ -309,12 +312,12 @@ def process_markdown(
     input_dir
     output_dir
     page_template, archive_template
-        templats for pages and articles
+        templates for pages and articles
 
     Returns
     -------
     list[tuple[str, dict[str, Any]]], list[tuple[str, dict[str, Any]]]
-        articles and pages
+        articles and pages, articles are sorted by date in descending order.
 
     """
     logger.info("Converting Markdown files...")
@@ -323,9 +326,9 @@ def process_markdown(
     articles = []
     pages = []
     for src, dst in convertibles:
-        logger.debug(f'Processing {src}')
+        logger.debug(f"Processing {src}")
 
-        with open(f'{input_dir}/{src}', 'r') as fh:
+        with open(f"{input_dir}/{src}", "r") as fh:
             body = fh.read()
 
         content, meta = convert_markdown(md, body)
@@ -335,17 +338,17 @@ def process_markdown(
 
         # if markdown has date in meta, we treat it as a blog article,
         # everything else are just pages
-        if meta and 'date' in meta:
+        if meta and "date" in meta:
             articles.append((dst, context))
             result = article_template.render(context)
         else:
             pages.append((dst, context))
             result = page_template.render(context)
-        with open(f'{output_dir}/{dst}', 'w') as fh_dest:
+        with open(f"{output_dir}/{dst}", "w") as fh_dest:
             fh_dest.write(result)
 
     # sort articles by date, descending
-    articles = sorted(articles, key=lambda x: x[1]['date'], reverse=True)
+    articles = sorted(articles, key=lambda x: x[1]["date"], reverse=True)
     return articles, pages
 
 
@@ -375,38 +378,40 @@ def generate_feed(
         blog author
 
     """
-    logger.info('Generating Atom feed.')
+    logger.info("Generating Atom feed.")
     feed = feedgenerator.Atom1Feed(
         link=base_url,
         title=blog_title,
         description=blog_description,
-        feed_url=base_url + 'atom.xml',
+        feed_url=base_url + "atom.xml",
     )
 
     for dst, context in articles:
         # if article has a description, use that. otherwise fall back to
         # the title
-        description = context.get('description', context['title'])
+        description = context.get("description", context["title"])
 
         feed.add_item(
-            title=context['title'],
+            title=context["title"],
             author_name=blog_author,
             link=base_url + dst,
             description=description,
-            content=context['content'],
-            pubdate=context['date'],
+            content=context["content"],
+            pubdate=context["date"],
         )
 
-    with open(f'{output_dir}/atom.xml', 'w') as fh:
-        feed.write(fh, encoding='utf8')
+    with open(f"{output_dir}/atom.xml", "w") as fh:
+        feed.write(fh, encoding="utf8")
 
 
-def generate_archive(
+def generate_index(
     articles: list[tuple[str, dict[str, Any]]],
     template: Template,
     output_dir: str,
 ) -> None:
-    """Generate the archive page.
+    """Generate the index page.
+
+    This is used for the index (i.e. landing) page.
 
     Parameters
     ----------
@@ -420,11 +425,40 @@ def generate_archive(
     archive = []
     for dst, context in articles:
         entry = context.copy()
-        entry['dst'] = dst
+        entry["dst"] = dst
         archive.append(entry)
 
     result = template.render(dict(archive=archive))
-    with open(f'{output_dir}/index.html', 'w') as fh:
+    with open(f"{output_dir}/index.html", "w") as fh:
+        fh.write(result)
+
+
+def generate_archive(
+    articles: list[tuple[str, dict[str, Any]]],
+    template: Template,
+    output_dir: str,
+) -> None:
+    """Generate the archive page.
+
+    This is used for the full archive.
+
+    Parameters
+    ----------
+    articles
+        List of articles. Each article has the destination path and a
+        dictionary with the content.
+    template
+    output_dir
+
+    """
+    archive = []
+    for dst, context in articles:
+        entry = context.copy()
+        entry["dst"] = dst
+        archive.append(entry)
+
+    result = template.render(dict(archive=archive))
+    with open(f"{output_dir}/archive.html", "w") as fh:
         fh.write(result)
 
 
@@ -446,11 +480,11 @@ def generate_tags(
 
     """
     logger.info("Generating Tag-pages.")
-    os.makedirs(f'{output_dir}/tags', exist_ok=True)
+    os.makedirs(f"{output_dir}/tags", exist_ok=True)
     # get tags number of occurrences
     all_tags: dict[str, int] = {}
     for _, context in articles:
-        tags: list[str] = context.get('tags', [])
+        tags: list[str] = context.get("tags", [])
         for tag in tags:
             all_tags[tag] = all_tags.get(tag, 0) + 1
     # sort by occurrence
@@ -459,25 +493,25 @@ def generate_tags(
     )
 
     result = tags_template.render(dict(tags=taglist))
-    with open(f'{output_dir}/tags/index.html', 'w') as fh:
+    with open(f"{output_dir}/tags/index.html", "w") as fh:
         fh.write(result)
 
     # get tags and archive per tag
     all_tags2: dict[str, list[dict[str, Any]]] = {}
     for dst, context in articles:
-        tags = context.get('tags', [])
+        tags = context.get("tags", [])
         for tag in tags:
             archive: list[dict[str, Any]] = all_tags2.get(tag, [])
             entry = context.copy()
-            entry['dst'] = dst
+            entry["dst"] = dst
             archive.append(entry)
             all_tags2[tag] = archive
 
     for tag, archive in all_tags2.items():
         result = tag_template.render(dict(archive=archive, tag=tag))
-        with open(f'{output_dir}/tags/{tag}.html', 'w') as fh:
+        with open(f"{output_dir}/tags/{tag}.html", "w") as fh:
             fh.write(result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
