@@ -1,56 +1,62 @@
 # remove when we don't support py38 anymore
 from __future__ import annotations
-from argparse import Namespace
-from typing import Iterator, Callable
-from tempfile import TemporaryDirectory
+
 import os
+from argparse import Namespace
+from tempfile import TemporaryDirectory
+from typing import Callable, Iterator
 
 import pytest
 from jinja2 import Environment, Template
 
-from blag import blag
+from blag import blag, quickstart
 
 
 @pytest.fixture
-def environment() -> Iterator[Environment]:
+def environment(cleandir: str) -> Iterator[Environment]:
     site = {
-        'base_url': 'site base_url',
-        'title': 'site title',
-        'description': 'site description',
-        'author': 'site author',
+        "base_url": "site base_url",
+        "title": "site title",
+        "description": "site description",
+        "author": "site author",
     }
-    env = blag.environment_factory(globals_=dict(site=site))
+    env = blag.environment_factory("templates", globals_=dict(site=site))
     yield env
 
 
 @pytest.fixture
 def page_template(environment: Environment) -> Iterator[Template]:
-    yield environment.get_template('page.html')
+    yield environment.get_template("page.html")
 
 
 @pytest.fixture
 def article_template(environment: Environment) -> Iterator[Template]:
-    yield environment.get_template('article.html')
+    yield environment.get_template("article.html")
+
+
+@pytest.fixture
+def index_template(environment: Environment) -> Iterator[Template]:
+    yield environment.get_template("index.html")
 
 
 @pytest.fixture
 def archive_template(environment: Environment) -> Iterator[Template]:
-    yield environment.get_template('archive.html')
+    yield environment.get_template("archive.html")
 
 
 @pytest.fixture
 def tags_template(environment: Environment) -> Iterator[Template]:
-    yield environment.get_template('tags.html')
+    yield environment.get_template("tags.html")
 
 
 @pytest.fixture
 def tag_template(environment: Environment) -> Iterator[Template]:
-    yield environment.get_template('tag.html')
+    yield environment.get_template("tag.html")
 
 
 @pytest.fixture
 def cleandir() -> Iterator[str]:
-    """Create a temporary workind directory and cwd."""
+    """Create a temporary working directory and cwd."""
     config = """
 [main]
 base_url = https://example.com/
@@ -60,13 +66,13 @@ author = a. u. thor
     """
 
     with TemporaryDirectory() as dir:
-        for d in 'content', 'build', 'static', 'templates':
-            os.mkdir(f'{dir}/{d}')
-        with open(f'{dir}/config.ini', 'w') as fh:
+        os.mkdir(f"{dir}/build")
+        with open(f"{dir}/config.ini", "w") as fh:
             fh.write(config)
         # change directory
         old_cwd = os.getcwd()
         os.chdir(dir)
+        quickstart.copy_default_theme()
         yield dir
         # and change back afterwards
         os.chdir(old_cwd)
@@ -74,11 +80,10 @@ author = a. u. thor
 
 @pytest.fixture
 def args(cleandir: Callable[[], Iterator[str]]) -> Iterator[Namespace]:
-
     args = Namespace(
-        input_dir='content',
-        output_dir='build',
-        static_dir='static',
-        template_dir='templates',
+        input_dir="content",
+        output_dir="build",
+        static_dir="static",
+        template_dir="templates",
     )
     yield args
